/****************************************************************************
    UART.c
    ------
    bungsprojekt zur Ausgabe von Daten mit dem UART.
    Es wird permanent ein Zhler inkrementiert und der Zhlerwert ber den
    UART ausgegeben.

    Autor:    Christian Schifferle
    Datum:    Oktober 2002
    Software: AVR-GCC
    needed
****************************************************************************/

#include <io.h>	// Wir brauchen Zugriff auf die I/O's des Controllers
#include <stdarg.h>
#include <ctype.h>
#include <string.h>

#include "UartPrintF.h"


#define F_CPU            8000000      /* 8Mhz */
#define UART_BAUD_RATE      9600      /* 9600 baud */

// Berechnung des Inhalts des UBBR-Registers
#define UART_BAUD_SELECT (F_CPU/(UART_BAUD_RATE*16l)-1)

// Datentypdefinitionen
typedef unsigned char	BYTE;
typedef unsigned short	WORD;

// Globale Variablen
WORD	nCounter;	// Zhlervariable, wird im SRAM abgelegt


// Funktionsprototypen
void UartInit (void);
void UartWrite (BYTE c);
int UartPrintF (const unsigned char *format, ...);




int main (void)
/****************************************************************************
    Hier ist der Programmeinstiegspunkt.
*/
{


    UartInit ();
    // Hier machen wir einmal etwas anderes zur Realisierung der
    // Endlosschleife. Wir setzen zu Beginn der Schleife ein Label.
    // Am Schleifenende springen wir direkt zu diesem Label.
    // Nicht schn, aber unheimlich schnell.
LOOP:
    UartPrintF ("Counter Dez:%6d, Uns:%5u, Hex:%4x, Oct:%6o\r\n",
               nCounter, nCounter, nCounter, nCounter);
    nCounter++;
goto LOOP;

} /* end of main */



void UartInit (void)
/***********************************************************************
    Initialieren des UART.
*/
{
    /* UART Control Register laden. Wir verwenden (noch)
       keine Interrupts. Vorerst wollen wir nur mal senden, also wird
       nur das Transmitter Enable Flag gesetzt. */
    outp ((1 << TXEN), UCR);

    /* Baudrate einstellen */
    outp ((BYTE) UART_BAUD_SELECT, UBRR);          

} /* end of UartInit */
